@@ -1,9 +1,10 @@
 anneal<-function(mat, kmin, kmax=kmin, nsol=1, niter=1000,
 exclude=NULL, include=NULL, improvement=TRUE, 
 setseed = FALSE, cooling=0.05, temp=1,
-coolfreq=1, criterion="RM", pcindices="first_k", initialsol=NULL,
+coolfreq=1, criterion="default", pcindices="first_k", initialsol=NULL,
 force=FALSE,H=NULL,r=0, tolval=10*.Machine$double.eps,tolsym=1000*.Machine$double.eps){
 
+
         
 #####################################
 #  set parameters to default values #
@@ -13,7 +14,7 @@ force=FALSE,H=NULL,r=0, tolval=10*.Machine$double.eps,tolsym=1000*.Machine$doubl
         if (r>0  && criterion=="default")  criterion <- "TAU_2"
         p <- nrow(mat)
 
-
+        
 ###############################
 # general validation of input #
 ###############################
@@ -23,15 +24,13 @@ force=FALSE,H=NULL,r=0, tolval=10*.Machine$double.eps,tolsym=1000*.Machine$doubl
         if ((p > maxnovar) & (force==FALSE)) stop("\n For very large data sets, memory problems may crash the R session. \n To proceed anyways, repeat the function call with \n the argument 'force' set to 'TRUE' (after saving anything important \n from the current session)\n")
         
 
-
 ######################################################################
 # Parameter validation if the criterion is one of "TAU_2", "XI_2",   #
-# "ZETA_2" or "CCR1_2"                                               #
+# "ZETA_2" or "CCR1_2" or "WALD"                                     #
 ######################################################################
 
 if (criterion == "TAU_2" || criterion == "XI_2" || criterion ==
-"ZETA_2" || criterion == "CCR1_2") validnovcrit(mat,criterion,H,r,p,tolval,tolsym)
-
+"ZETA_2" || criterion == "CCR1_2" || criterion == "WALD") validnovcrit(mat,criterion,H,r,p,tolval,tolsym)
 
 
 ##########################################################################
@@ -74,8 +73,20 @@ if (criterion == "TAU_2" || criterion == "XI_2" || criterion ==
 ##################################
 # call to the Fortran subroutine #
 ##################################
+         
+	if (criterion == "WALD")   {
 
-        Fortout<-.Fortran("anneal",as.integer(criterio),as.integer(p),
+###       Convert a min Wald problem into an (artificial) equivalent max XI2 problem
+        
+        	Waldval <- sum(diag(solve(mat,H)))
+            	H <- H / Waldval     
+	    	criterion <- "XI_2"
+		criterio <- 5
+		Walddec <- TRUE
+	}
+        else Walddec <- FALSE
+
+       Fortout<-.Fortran("anneal",as.integer(criterio),as.integer(p),
           as.double(as.vector(mat)),
           as.integer(kmin),as.integer(kmax),as.double(valores),
           as.integer(vars),as.double(bestval),as.integer(bestvar),
@@ -102,5 +113,13 @@ if (criterion == "TAU_2" || criterion == "XI_2" || criterion ==
         dimnames(bestvar)<-list(paste("Card",kmin:kmax,sep="."),paste("Var",1:kmax,sep="."))
         output<-list(variaveis,valores,bestval,bestvar,match.call())
         names(output)<-c("subsets","values","bestvalues","bestsets","call")
+        if (Walddec)  {
+		criterion <- "WALD"
+		criterio <- 8
+		validvalues <- output$values[output$values > 0.]
+		output$values[output$values > 0.] <- rep(Waldval,length(validvalues)) - validvalues*Waldval 
+		output$bestvalues <- rep(Waldval,kmax-kmin+1) - output$bestvalues*Waldval
+      }	
         output}
 
+
