@@ -1,4 +1,4 @@
-xi2.coef<-function(mat, H=NULL,r=0,indices, tolval=10*.Machine$double.eps, tolsym=1000*.Machine$double.eps)
+xi2.coef<-function(mat,H,r,indices, tolval=10*.Machine$double.eps, tolsym=1000*.Machine$double.eps)
 {
 #   Function xi_2.coef
 #   Computes the xi^2 index of "effect magnitude".  
@@ -26,27 +26,27 @@ xi2.coef<-function(mat, H=NULL,r=0,indices, tolval=10*.Machine$double.eps, tolsy
 
       tr<-function(mat){sum(diag(mat))}
 
-      rm.1d<-function(mat,H,r,indices){
+      xi2.1d<-function(mat,H,r,indices){
 		l <- min(r,length(indices))
-	tr(H[indices,indices]%*%solve(mat[indices,indices]))/l	
+	tr(solve(mat[indices,indices],H[indices,indices]))/l	
        }
       dimension<-length(dim(indices))
       if (dimension > 1){
-         rm.2d<-function(mat,H,r,subsets){
+         xi2.2d<-function(mat,H,r,subsets){
              apply(subsets,1,function(indices){
 			
-			rm.1d(mat,H,r,indices)})
+			xi2.1d(mat,H,r,indices)})
             }  
              if (dimension > 2) {
-               rm.3d<-function(mat,H,r,array3d){
-                   apply(array3d,3,function(subsets){rm.2d(mat,H,r,subsets)})
+               xi2.3d<-function(mat,H,r,array3d){
+                   apply(array3d,3,function(subsets){xi2.2d(mat,H,r,subsets)})
                  }
-               output<-rm.3d(mat,H=H,r,indices)
+               output<-xi2.3d(mat,H=H,r,indices)
               }
-              if (dimension == 2) {output<-rm.2d(mat=mat,H,r,indices)}
+              if (dimension == 2) {output<-xi2.2d(mat=mat,H,r,indices)}
       }
 
-      if (dimension < 2) {output<-rm.1d(mat,H,r,indices)}
+      if (dimension < 2) {output<-xi2.1d(mat,H,r,indices)}
       output
 }
 
